FeedbackButton — pyqtgraph 0.11.0rc0 documentation

# FeedbackButton

class `pyqtgraph.` `FeedbackButton`(*args)

  QPushButton which flashes success/failure indication for slow or asynchronous procedures.

  `__init__`(*args)

    Initialize self. See help(type(self)) for accurate signature.

  `failure`(message=None, tip='', limitedTime=True)

    Displays specified message on button and flashes button red to let user know there was an error. If you want the error to be displayed until the user takes an action, set limitedTime to False. Then call self.reset() after the desired action. Threadsafe.

  `feedback`(success, message=None, tip='', limitedTime=True)

    Calls success() or failure(). If you want the message to be displayed until the user takes an action, set limitedTime to False. Then call self.reset() after the desired action.Threadsafe.

  `processing`(message='Processing..', tip='', processEvents=True)

    Displays specified message on button to let user know the action is in progress. Threadsafe.

  `reset`()

    Resets the button to its original text and style. Threadsafe.

  `setStyleSheet`(self, styleSheet: str)
  `setText`(self, text: str)
  `setToolTip`(self, arg__1: str)
  `success`(message=None, tip='', limitedTime=True)

    Displays specified message on button and flashes button green to let user know action was successful. If you want the success to be displayed until the user takes an action, set limitedTime to False. Then call self.reset() after the desired action. Threadsafe.